@echo off

REM This script can be used to create a bootable CD with enough facilities
REM to fully manage and recover your system.
REM It contains support for LVM, HPFS, JFS, FAT32 and CD.  The total space
REM occupied is less than five MB!

REM Personally I use it on the CD-RWs I burn my system backups to.
REM Recovering/reinstalling the system just takes booting-off this CD,
REM optionally managing (lvm) and formatting volumes, and unzipping the
REM backup-zip files that are also on the CD!

REM Present settings assume an IDE only setup, instuctions for adding SCSI
REM support are included (not yet tested, however).  If you need extra
REM space on the boot image (for instance if you added SCSI support),
REM instructions for moving some files to the CD are included as well.
REM Currently all files absolutely required to boot are in the boot
REM image; during boot, no files from the CD are required.

REM The script assumes you use RSJ for burning CDs and that you have
REM already attached the CD-R(W).  It furthermore assumes you use the DANI
REM drivers for accessing IDE and ATAPI devices as these are the most
REM stable.

REM The following drive letters and contents are assumed:
REM     H:\BootCD Directory where daniboot.flt and the specific config.sys
REM               reside 
REM     O:        Your eCS partition
REM     T:        A 2.88MB virtual floppy
REM     W:        Drive letter where your cd-r is attached

REM How to obtain the required files:
REM     All required extra files can be obtained from Hobbes:
REM     savedskf.exe: search for loaddf.zip
REM     daniboot.flt: search for daniboot
REM     danis506.add: search for danis506
REM     daniatap.flt: search for daniatapi
REM     fat32.ifs and ufat32.dll: search for os2fat32

REM Thanks go to Allan Dermody for providing CD_BOOT.FLT and the
REM first insight into creating bootable CD's

REM Thanks also go to Alfrede Fernandez Diaz for writing an excelent
REM article on how to create a bootable CD in OS2Voice, July 2000
REM http://www.os2voice.org/VNL/past_issues/VNL0700H/vnewsf2.htm

REM More thanks go to Daniela Engert for writing the DANI suite of
REM device drivers and filters.

REM Enjoy,
REM     Hayo Baan, hrbaan@xs4all.nl


REM Version History ----------------------------------------------
REM v1.1 21/02/2002: Now using daniboot.flt instead of cdboot.flt
REM v1.0 16/02/2002: Original version


REM *************************************************************************
REM **** Boot Image *********************************************************
REM *************************************************************************

REM Install system files ----------------------------------------------------

rem Format the virtual disk
format t: /fs:fat /once /v:CD-BOOT

rem Install system files
O:\TVoice\Wiseprog\BooteCS\required\sysinstx T:
xcopy /h/t/r o:\os2ldr     t:\
xcopy /h/t/r o:\os2ldr.msg t:\
xcopy /h/t/r o:\os2krnl    t:\
xcopy /h/t/r o:\os2logo    t:\

rem This is the config.sys specially prepared for the boot cd
copy  h:\bootcd\config.sys t:\


REM Vital files -------------------------------------------------------------

rem OS/2 directory tree
mkdir t:\OS2
mkdir t:\OS2\BOOT
mkdir t:\OS2\DLL

rem Vital device drivers
copy o:\os2\boot\clock01.sys   t:\os2\boot
copy o:\os2\boot\isapnp.snp    t:\os2\boot
copy o:\os2\boot\kbdbase.sys   t:\os2\boot
copy o:\os2\boot\pnp.sys       t:\os2\boot
copy o:\os2\boot\resource.sys  t:\os2\boot
copy o:\os2\boot\screen01.sys  t:\os2\boot
copy o:\os2\boot\ibmkbd.sys    t:\os2\boot

rem Vital dlls
copy o:\os2\dll\bkscalls.dll   t:\os2\dll
copy o:\os2\dll\bmscalls.dll   t:\os2\dll
copy o:\os2\dll\bvhvga.dll     t:\os2\dll
copy o:\os2\dll\bvscalls.dll   t:\os2\dll
copy o:\os2\dll\doscall1.dll   t:\os2\dll
copy o:\os2\dll\kbdcalls.dll   t:\os2\dll
copy o:\os2\dll\moucalls.dll   t:\os2\dll
copy o:\os2\dll\msg.dll        t:\os2\dll
copy o:\os2\dll\nls.dll        t:\os2\dll
copy o:\os2\dll\npxemltr.dll   t:\os2\dll
copy o:\os2\dll\os2char.dll    t:\os2\dll
copy o:\os2\dll\quecalls.dll   t:\os2\dll
copy o:\os2\dll\sesmgr.dll     t:\os2\dll
copy o:\os2\dll\viocalls.dll   t:\os2\dll

rem Country.sys
copy o:\os2\system\country.sys t:\os2

rem Codepages and keyboard files
copy o:\os2\boot\viotbl.dcp    t:\os2\boot
copy o:\os2\keyboard.dcp       t:\os2\boot

rem Necessary for a boot cd
copy h:\bootcd\daniboot.flt    t:\os2\boot

rem Access to storage devices
copy o:\os2\boot\os2dasd.dmd   t:\os2\boot

rem Floppy support, leave out if you don't need it
copy o:\os2\boot\ibm1flpy.add  t:\os2\boot

rem Fallback HD support, leave out if you don't need it
rem copy o:\os2\boot\ibmint13.i13  t:\os2\boot

rem IDE support, you can leave this out if you don't have IDE
copy o:\os2\boot\danis506.add  t:\os2\boot

rem SCSI support, you can leave this out if you don't have SCSI
rem copy o:\os2\boot\<scsi-adapter> t:\os2\boot
rem copy o:\os2\boot\os2aspi.dmd    t:\os2\boot

rem These vital files could possibly reside on the cd instead
copy o:\os2\boot\mouse.sys    t:\os2
copy o:\os2\boot\pointdd.sys  t:\os2
copy o:\os2\boot\testcfg.sys  t:\os2

REM CDFS support ------------------------------------------------------------
copy o:\os2\boot\os2cdrom.dmd t:\os2\boot
copy o:\os2\boot\cdfs.ifs     t:\os2\boot
rem If you have a scsi cd-rom you can leave this out
copy o:\os2\boot\daniatap.flt t:\os2\boot

REM HPFS support ------------------------------------------------------------
copy o:\os2\hpfs.ifs          t:\os2\boot

REM FAT 32 support ----------------------------------------------------------
copy o:\os2\fat32.ifs         t:\os2\boot

REM LVM support -------------------------------------------------------------
copy o:\os2\boot\os2lvm.dmd   t:\os2\boot

REM JFS support -------------------------------------------------------------
copy o:\os2\jfs.ifs           t:\os2\boot

REM Unicode support (necessary for full jfs support) ------------------------
copy o:\os2\boot\unicode.sys  t:\os2\boot
rem Language directory tree
mkdir t:\LANGUAGE
mkdir t:\LANGUAGE\CODEPAGE
mkdir t:\LANGUAGE\EN
mkdir t:\LANGUAGE\FONT
mkdir t:\LANGUAGE\KEYBOARD
mkdir t:\LANGUAGE\LOCALE
rem Replace with your codepage, language, and keyboard set-up
copy o:\language\codepage\ibm850      t:\language\codepage
copy o:\language\en\ehx*.*            t:\language\en
copy o:\language\keyboard\usinter.kbl t:\language\keyboard
copy o:\language\locale\user.loc      t:\language\locale

REM The shell ---------------------------------------------------------------
rem could be replaced and possibly reside on the cd instead
copy o:\os2\cmd.exe t:\os2

REM Create the boot image ---------------------------------------------------
savedskf /a/d t: h:\bootcd\bootcd.img
copy h:\bootcd\bootcd.img w:
rem Mark the image as bootable
cdboot w:\bootcd.img

REM *************************************************************************
REM **** Support Files on CD ************************************************
REM *************************************************************************

rem Directory tree
mkdir w:\OS2
mkdir w:\OS2\DLL

rem Some nice to have commands
copy o:\os2\attrib.exe         w:\os2
copy o:\os2\chkdsk.com         w:\os2
copy o:\os2\chkdsk32.exe       w:\os2
copy o:\os2\format.com         w:\os2
copy o:\os2\mode.com           w:\os2
copy o:\os2\more.com           w:\os2
copy o:\os2\tedit.exe          w:\os2
copy o:\os2\xcopy.exe          w:\os2

rem Necessary message files
copy o:\os2\system\oso001.msg  w:\os2
copy o:\os2\system\oso001h.msg w:\os2

rem Necessary dlls
copy o:\os2\dll\ansicall.dll   w:\os2\dll
copy o:\os2\dll\bvhwndw.dll    w:\os2\dll
copy o:\os2\dll\chkdsk32.dll   w:\os2\dll
copy o:\os2\dll\nampipes.dll   w:\os2\dll

rem CDFS support
copy o:\os2\system\ucdfs.msg   w:\os2
copy o:\os2\dll\ucdfs.dll      w:\os2\dll

rem HPFS support
copy o:\os2\dll\uhpfs.dll      w:\os2\dll

rem FAT32 support
copy o:\os2\dll\ufat32.dll     w:\os2\dll

rem LVM support
copy o:\os2\lvm.exe            w:\os2
copy o:\os2\system\lvm.msg     w:\os2
copy o:\os2\system\lvmh.msg    w:\os2
copy o:\os2\dll\lvm.dll        w:\os2\dll

rem JFS support
copy o:\os2\jfschk32.exe       w:\os2
copy o:\os2\jfs.msg            w:\os2
copy o:\os2\jfsh.msg           w:\os2
copy o:\os2\dll\ujfs.dll       w:\os2\dll

rem Unicode support (necessary for full JFS support)
copy o:\os2\dll\uconv.dll      w:\os2\dll
